:mod:`pylons.templating` -- Render functions and helpers
========================================================

.. automodule:: pylons.templating

Module Contents
---------------

.. autofunction:: pylons_globals
.. autofunction:: cached_template
.. autofunction:: render_mako
.. autofunction:: render_mako_def
.. autofunction:: render_genshi
